## Relatório de Acompanhamento de vagas em câmpus fora de sede
### Indica a quantidade de vagas ocupadas pelos estudantes em cada disciplina dos Campus Fora de Sede (CFS).

#### Recebe como entrada o seguintes relatório extraído do sistema Prime:
 - Relatório de Carga Horária por turma / disciplina.
#### Não contem a informação de salas nem de capacidade
#### Utilizado diariamente durante o período de Ajuste Acadêmico
